Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(202)

Unified Diff: net/http/http_server_properties.h

Issue 2886273002: Change GetAlternativeServies to return alternative service infos. (Closed)
Patch Set: self review Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/http/http_server_properties.h
diff --git a/net/http/http_server_properties.h b/net/http/http_server_properties.h
index 3a264a9bce74f3cdad97f95cba6c06d26e6c2691..18c0a0681d70a6e4465efcde74d662ecbaf8b0f5 100644
--- a/net/http/http_server_properties.h
+++ b/net/http/http_server_properties.h
@@ -238,9 +238,9 @@ class NET_EXPORT HttpServerProperties {
virtual void MaybeForceHTTP11(const HostPortPair& server,
SSLConfig* ssl_config) = 0;
- // Return all alternative services for |origin|, including broken ones.
- // Returned alternative services never have empty hostnames.
- virtual AlternativeServiceVector GetAlternativeServices(
+ // Return all alternative service infos for |origin|, including broken ones.
+ // Returned alternative service infos never have empty hostnames.
Ryan Hamilton 2017/05/18 17:45:33 nit: I think you can remove "infos" from the comme
Zhongyi Shi 2017/05/18 19:24:38 Done.
+ virtual AlternativeServiceInfoVector GetAlternativeServiceInfos(
const url::SchemeHostPort& origin) = 0;
// Set a single alternative service for |origin|. Previous alternative

Powered by Google App Engine
This is Rietveld 408576698